@@ -209,12 +209,20 @@ class ProductTests(unittest.TestCase):
     def test_create_paid_customer_with_charges(self):
         data = copy(self.paid_defaults)
         charges = []
-        charges.append({'code': 'test_charge_1', 'each_amount': Decimal('2.30')})
-        charges.append({'code': 'charge2', 'amount': 3, 'each_amount': 4})
+        charges.append({'code': 'test_charge_1', 'each_amount':2})
+        charges.append({'code': 'charge2', 'quantity': 3, 'each_amount': 4})
         data['charges'] = charges
         self.get_customer(**data)
         
-        
+    @clear_users
+    def test_create_paid_customer_with_decimal_charges(self):
+        data = copy(self.paid_defaults)
+        charges = []
+        charges.append({'code': 'test_charge_1', 'each_amount': Decimal('2.30')})
+        charges.append({'code': 'charge2', 'each_amount': Decimal('-4.5')})
+        data['charges'] = charges
+        self.get_customer(**data)
+
     @clear_users
     def test_create_paid_customer_with_items(self):
         data = copy(self.paid_defaults)
@@ -225,6 +233,17 @@ class ProductTests(unittest.TestCase):
         data['plan_code'] = 'TRACKED_MONTHLY'
         self.get_customer(**data)
 
+    
+    @clear_users
+    def test_create_paid_customer_with_decimal_quantity_items(self):
+        data = copy(self.paid_defaults)
+        items = []
+        items.append({'code': 'MONTHLY_ITEM', 'quantity': Decimal('1.23456')})
+        items.append({'code': 'ONCE_ITEM'})
+        data['items'] = items
+        data['plan_code'] = 'TRACKED_MONTHLY'
+        self.get_customer(**data)
+
     @clear_users
     def test_create_paypal_customer(self):
         data = copy(self.paypal_defaults)
